pub async fn delete_attachment<R: Repository<Cipher> + ?Sized>(
cipher_id: CipherId,
attachment_id: &str,
api_client: &ApiClient,
repository: &R,
) -> Result<Cipher, CipherDeleteAttachmentError>Expand description
Deletes an attachment from a cipher, and updates the local repository with the new cipher data returned from the API.